is

package
v0.0.0-...-81735e3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 16, 2024 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package is implements functions for testing to assure that values are in a desired state.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Equal

func Equal[T comparable](t *testing.T, actual, expected T)

Equal compares actual and expected. It errors if the values are not equal.

func False

func False(t *testing.T, arg bool)

False compares arg to false. It errors if the value is not false.

func Nil

func Nil[T comparable](t *testing.T, arg T)

Equal compares arg to nil. It errors if the value is not nil or if arg can't be nil because of its type.

func NotEqual

func NotEqual[T comparable](t *testing.T, actual, expected T)

Equal compares actual and expected. It errors if the values are equal.

func True

func True(t *testing.T, arg bool)

True compares arg to true. It errors if the value is not true.

Types

This section is empty.

Jump to