Documentation
¶
Overview ¶
Package is implements functions for testing to assure that values are in a desired state.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Equal ¶
func Equal[T comparable](t *testing.T, actual, expected T)
Equal compares actual and expected. It errors if the values are not equal.
func Nil ¶
func Nil[T comparable](t *testing.T, arg T)
Equal compares arg to nil. It errors if the value is not nil or if arg can't be nil because of its type.
func NotEqual ¶
func NotEqual[T comparable](t *testing.T, actual, expected T)
Equal compares actual and expected. It errors if the values are equal.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.